==> igniteui-react-core-18.2.0-beta.0.tgz: package/esm5/lib/WebComboDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOptionsDescriptionMetadata } from "./WebFilteringOptionsDescriptionMetadata";
import { WebComboChangeEventArgsDescriptionMetadata } from "./WebComboChangeEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebComboDescription } from "./WebComboDescription";
/**
 * @hidden
 */
var WebComboDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebComboDescriptionMetadata, _super);
    function WebComboDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebComboDescriptionMetadata.b = function (a) {
        if (WebComboDescriptionMetadata.a == null) {
            WebComboDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebComboDescriptionMetadata.c(WebComboDescriptionMetadata.a);
        }
        if (a.k(WebComboDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebComboDescriptionMetadata.a);
        WebFilteringOptionsDescriptionMetadata.d(a);
        WebComboChangeEventArgsDescriptionMetadata.d(a);
        VoidEventArgsDescriptionMetadata.d(a);
    };
    WebComboDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Combo");
        a.item("__tagNameWC", "String:igc-combo");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("DataRef", "(w:Data,wf:Data)DataRef::object");
        a.item("Name", "String");
        a.item("Disabled", "Boolean");
        a.item("Required", "Boolean");
        a.item("Invalid", "Boolean");
        a.item("Outlined", "Boolean");
        a.item("SingleSelect", "Boolean");
        a.item("Autofocus", "Boolean");
        a.item("AutofocusList", "Boolean");
        a.item("Label", "String");
        a.item("Placeholder", "String");
        a.item("PlaceholderSearch", "String");
        a.item("Dir", "ExportedType:string:ComboDir");
        a.item("Dir@stringUnion", "WebComponents;React");
        a.item("Dir@names", "Ltr;Rtl;Auto");
        a.item("Open", "Boolean");
        a.item("ValueKey", "String");
        a.item("DisplayKey", "String");
        a.item("GroupKey", "String");
        a.item("GroupSorting", "ExportedType:string:GroupingDirection");
        a.item("GroupSorting@stringUnion", "WebComponents;React");
        a.item("GroupSorting@names", "Asc;Desc");
        a.item("FilteringOptions", "ExportedType:WebFilteringOptions");
        a.item("CaseSensitiveIcon", "Boolean");
        a.item("DisableFiltering", "Boolean");
        a.item("ItemTemplateRef", "(w:ItemTemplate,wf:ItemTemplate)TemplateRef::object");
        a.item("GroupHeaderTemplateRef", "(w:GroupHeaderTemplate,wf:GroupHeaderTemplate)TemplateRef::object");
        a.item("ChangeRef", "EventRef::change");
        a.item("FocusRef", "EventRef::focus");
        a.item("BlurRef", "EventRef::blur");
        a.item("OpeningRef", "EventRef::opening");
        a.item("OpenedRef", "EventRef::opened");
        a.item("ClosingRef", "EventRef::closing");
        a.item("ClosedRef", "EventRef::closed");
    };
    WebComboDescriptionMetadata.d = function (a) {
        WebComboDescriptionMetadata.b(a);
        a.ad("WebCombo", function () { return new WebComboDescription(); });
        a.ac("WebCombo", WebComboDescriptionMetadata.a);
    };
    WebComboDescriptionMetadata.$t = markType(WebComboDescriptionMetadata, 'WebComboDescriptionMetadata');
    WebComboDescriptionMetadata.a = null;
    return WebComboDescriptionMetadata;
}(Base));
export { WebComboDescriptionMetadata };

==> igniteui-react-core-18.5.2-beta.0.tgz: package/esm5/lib/WebComboDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOptionsDescriptionMetadata } from "./WebFilteringOptionsDescriptionMetadata";
import { WebComboChangeEventArgsDescriptionMetadata } from "./WebComboChangeEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebComboDescription } from "./WebComboDescription";
/**
 * @hidden
 */
var WebComboDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebComboDescriptionMetadata, _super);
    function WebComboDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebComboDescriptionMetadata.b = function (a) {
        if (WebComboDescriptionMetadata.a == null) {
            WebComboDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebComboDescriptionMetadata.c(WebComboDescriptionMetadata.a);
        }
        if (a.k(WebComboDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebComboDescriptionMetadata.a);
        WebFilteringOptionsDescriptionMetadata.d(a);
        WebComboChangeEventArgsDescriptionMetadata.d(a);
        VoidEventArgsDescriptionMetadata.d(a);
    };
    WebComboDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Combo");
        a.item("__tagNameWC", "String:igc-combo");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("DataRef", "(w:Data,wf:Data)DataRef::object");
        a.item("Outlined", "Boolean");
        a.item("SingleSelect", "Boolean");
        a.item("Autofocus", "Boolean");
        a.item("AutofocusList", "Boolean");
        a.item("Label", "String");
        a.item("Placeholder", "String");
        a.item("PlaceholderSearch", "String");
        a.item("Open", "Boolean");
        a.item("ValueKey", "String");
        a.item("DisplayKey", "String");
        a.item("GroupKey", "String");
        a.item("GroupSorting", "ExportedType:string:GroupingDirection");
        a.item("GroupSorting@stringUnion", "WebComponents;React");
        a.item("GroupSorting@names", "Asc;Desc;None");
        a.item("FilteringOptions", "ExportedType:WebFilteringOptions");
        a.item("CaseSensitiveIcon", "Boolean");
        a.item("DisableFiltering", "Boolean");
        a.item("Value", "Array:object");
        a.item("Disabled", "Boolean");
        a.item("Required", "Boolean");
        a.item("Invalid", "Boolean");
        a.item("ItemTemplateRef", "(w:ItemTemplate,wf:ItemTemplate)TemplateRef::object");
        a.item("GroupHeaderTemplateRef", "(w:GroupHeaderTemplate,wf:GroupHeaderTemplate)TemplateRef::object");
        a.item("ChangeRef", "EventRef::change");
        a.item("FocusRef", "EventRef::focus");
        a.item("BlurRef", "EventRef::blur");
        a.item("OpeningRef", "EventRef::opening");
        a.item("OpenedRef", "EventRef::opened");
        a.item("ClosingRef", "EventRef::closing");
        a.item("ClosedRef", "EventRef::closed");
    };
    WebComboDescriptionMetadata.d = function (a) {
        WebComboDescriptionMetadata.b(a);
        a.ad("WebCombo", function () { return new WebComboDescription(); });
        a.ac("WebCombo", WebComboDescriptionMetadata.a);
    };
    WebComboDescriptionMetadata.$t = markType(WebComboDescriptionMetadata, 'WebComboDescriptionMetadata');
    WebComboDescriptionMetadata.a = null;
    return WebComboDescriptionMetadata;
}(Base));
export { WebComboDescriptionMetadata };
